=======
History
=======

0.1.2 (2020-10-20)
------------------

* Add API documentation.
* Formulate docstrings for all member functions.
* Add section with features to README.

0.1.0 (2020-10-20)
------------------

* First release on PyPI.
